==> openGion_dev_5.0.2.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/io/TableWriter_Renderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.io;

import org.opengion.hayabusa.db.DBTableModel;
import org.opengion.fukurou.util.StringUtil;

import java.io.PrintWriter;

/**
 * 表示種別(RENDERER)適用ダブルクォートゼロカンマ区切り文字指定データの書き出しクラスです。
 *
 * DefaulTableWriter_Renderer を継承して，データの出力部のみオーバーライドして，
 * テーブルデータではなく、表示文字列（レンデラー情報）を出力します。
 *
 * @og.rev 3.1.5.0 (2003/04/22) 新規作成
 * @og.group ファイル出力
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TableWriter_Renderer extends TableWriter_Default {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	/**
	 * PrintWriter に DBTableModelのテーブル情報を書き込みます。
	 *
	 * @og.rev 3.7.0.2 (2005/02/14) 行番号情報を、出力する(true)/しない(false)を指定
	 * @og.rev 3.8.0.1 (2005/06/17) DBTypeが NVAR の場合は、元のUnicodeに戻します。
	 * @og.rev 3.8.0.5 (2005/08/20) 検索結果が、&lt;span ･･･&gt;XXXX&lt;/span&gt;形式の場合、XXXX のみ出力します。
	 * @og.rev 3.8.0.9 (2005/10/17) 先頭がゼロの文字型のデータには、カンマ(')を追加します。
	 * @og.rev 4.3.4.3 (2008/12/22) spanCutをfukurouに移動
	 *
	 * @param	table DBTableModel
	 * @param	writer PrintWriter
	 */
	protected void writeData( final DBTableModel table,final PrintWriter writer ) {

		// 3.8.0.9 (2005/10/17) タイプチェック ＆ キャッシュ
		int[] typeFlag = new int[numberOfColumns];
		for( int i=0; i<numberOfColumns; i++ ) {
			int clm = clmNo[i];
			String type =  dbColumn[clm].getDbType();
			if( "NVAR".equals( type ) ) {
				typeFlag[i] = 1;			// NVAR の場合 1
			}
			else if( NUMBER_TYPE_LIST.indexOf( type ) < 0 ) {
				typeFlag[i] = 2;			// 数字タイプでない場合 2
			}
			else {
				typeFlag[i] = 0;			// それ以外
			}
		}

		int numberOfRows = table.getRowCount();
		String SEPARATOR = getSeparator();
		boolean useNumber = isUseNumber();

		for( int row=0; row<numberOfRows; row++ ) {
			if( useNumber ) {
				writer.print( String.valueOf( row+1 ) );
				writer.print( SEPARATOR );
			}
			for( int i=0; i<numberOfColumns; i++ ) {
				int clm = clmNo[i];
				if( i != 0 ) { writer.print( SEPARATOR ); }

				String val = table.getValue(row,clm);
				if( typeFlag[i] == 1 ) {
					val = StringUtil.getReplaceEscape( val );
				}
				else {
					val = StringUtil.spanCut( dbColumn[clm].getRendererValue( val ) ); //4.3.4.3 (2008/12/22)
				}

				if( typeFlag[i] == 2 && val != null && val.length() > 0 && val.charAt(0) == '0' ) {
					writer.print( "'" );		// 開始日などの 00000000 を文字列タイプで渡す
				}
				writer.print( val );
			}
			writer.println();
		}
	}
}

==> openGion_dev_5.1.6.0.zip: opengion/uap/webapps/gf/src/org/opengion/plugin/io/TableWriter_Renderer.java <==
/*
 * Copyright (c) 2009 The openGion Project.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.opengion.plugin.io;

import org.opengion.hayabusa.db.DBTableModel;
import org.opengion.fukurou.util.StringUtil;

import java.io.PrintWriter;

/**
 * 表示種別(RENDERER)適用ダブルクォートゼロカンマ区切り文字指定データの書き出しクラスです。
 *
 * DefaulTableWriter_Renderer を継承して，データの出力部のみオーバーライドして，
 * テーブルデータではなく、表示文字列（レンデラー情報）を出力します。
 *
 * @og.rev 3.1.5.0 (2003/04/22) 新規作成
 * @og.group ファイル出力
 *
 * @version  4.0
 * @author	 Kazuhiko Hasegawa
 * @since    JDK5.0,
 */
public class TableWriter_Renderer extends TableWriter_Default {
	//* このプログラムのVERSION文字列を設定します。	{@value} */
	private static final String VERSION = "4.0.0 (2005/08/31)" ;

	/**
	 * PrintWriter に DBTableModelのテーブル情報を書き込みます。
	 *
	 * @og.rev 3.7.0.2 (2005/02/14) 行番号情報を、出力する(true)/しない(false)を指定
	 * @og.rev 3.8.0.1 (2005/06/17) DBTypeが NVAR の場合は、元のUnicodeに戻します。
	 * @og.rev 3.8.0.5 (2005/08/20) 検索結果が、&lt;span ･･･&gt;XXXX&lt;/span&gt;形式の場合、XXXX のみ出力します。
	 * @og.rev 3.8.0.9 (2005/10/17) 先頭がゼロの文字型のデータには、カンマ(')を追加します。
	 * @og.rev 4.3.4.3 (2008/12/22) spanCutをfukurouに移動
	 * @og.rev 5.1.6.0 (2010/05/01) DbType の初期値(dbType)を利用する。
	 *
	 * @param	table DBTableModel
	 * @param	writer PrintWriter
	 */
	protected void writeData( final DBTableModel table,final PrintWriter writer ) {

		// 3.8.0.9 (2005/10/17) タイプチェック ＆ キャッシュ
//		int[] typeFlag = new int[numberOfColumns];
//		for( int i=0; i<numberOfColumns; i++ ) {
//			int clm = clmNo[i];
//			String type =  dbColumn[clm].getDbType();
//			if( "NVAR".equals( type ) ) {
//				typeFlag[i] = 1;			// NVAR の場合 1
//			}
//			else if( NUMBER_TYPE_LIST.indexOf( type ) < 0 ) {
//				typeFlag[i] = 2;			// 数字タイプでない場合 2
//			}
//			else {
//				typeFlag[i] = 0;			// それ以外
//			}
//		}

		int numberOfRows = table.getRowCount();
		String SEPARATOR = getSeparator();
		boolean useNumber = isUseNumber();

		for( int row=0; row<numberOfRows; row++ ) {
			if( useNumber ) {
				writer.print( String.valueOf( row+1 ) );
				writer.print( SEPARATOR );
			}
			for( int i=0; i<numberOfColumns; i++ ) {
				int clm = clmNo[i];
				if( i != 0 ) { writer.print( SEPARATOR ); }

				String val = table.getValue(row,clm);
//				if( typeFlag[i] == 1 ) {
				if( dbType[i] == NVAR ) {
					val = StringUtil.getReplaceEscape( val );
				}
				else {
					val = StringUtil.spanCut( dbColumn[clm].getRendererValue( val ) ); //4.3.4.3 (2008/12/22)
				}

//				if( typeFlag[i] == 2 && val != null && val.length() > 0 && val.charAt(0) == '0' ) {
				if( val != null && val.length() > 0 && val.charAt(0) == '0' &&
					dbType[i] == NUMBER ) {
					writer.print( "'" );		// 開始日などの 00000000 を文字列タイプで渡す
				}
				writer.print( val );
			}
			writer.println();
		}
	}
}
